@@ -1,186 +1,143 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="hu">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="hu">
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.ui" line="14"/>
+        <location filename="mainwindow.ui" line="14"/>
         <source>Program_Name</source>
         <translation>Program_Name</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="29"/>
+        <location filename="mainwindow.ui" line="29"/>
         <source>Usage</source>
         <translation>Használata</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="229"/>
+        <location filename="mainwindow.ui" line="106"/>
         <source>Dock Preview</source>
         <translation>Dokk előnézet</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="241"/>
+        <location filename="mainwindow.ui" line="118"/>
         <source>Add New Application</source>
         <translation>Új alkalmazás hozzáadása</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="641"/>
+        <location filename="mainwindow.ui" line="131"/>
         <source>Command</source>
         <translation>Parancs</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="118"/>
+        <location filename="mainwindow.ui" line="301"/>
         <source>Add application</source>
         <translation>Alkalmazás hozzáadása</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="212"/>
+        <location filename="mainwindow.ui" line="393"/>
         <source>Delete this application</source>
         <translation>Alkalmazás törlése</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="400"/>
+        <location filename="mainwindow.ui" line="124"/>
         <source>Border</source>
         <translation>Keret</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="247"/>
+        <location filename="mainwindow.ui" line="154"/>
         <source>Size</source>
         <translation>Méret</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="664"/>
+        <location filename="mainwindow.ui" line="161"/>
         <source>Background</source>
         <translation>Háttér</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="198"/>
+        <location filename="mainwindow.ui" line="379"/>
         <source>Back</source>
         <translation>Vissza</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="465"/>
+        <location filename="mainwindow.ui" line="184"/>
         <source>File</source>
         <translation>Fájl</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="504"/>
-        <location filename="../mainwindow.cpp" line="861"/>
-        <location filename="../mainwindow.cpp" line="979"/>
-        <location filename="../mainwindow.cpp" line="1017"/>
-        <location filename="../mainwindow.cpp" line="1042"/>
+        <location filename="mainwindow.ui" line="216"/>
+        <location filename="mainwindow.cpp" line="708"/>
+        <location filename="mainwindow.cpp" line="735"/>
         <source>Select icon...</source>
         <translation>Ikon kiválasztása...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="677"/>
-        <location filename="../mainwindow.cpp" line="102"/>
-        <location filename="../mainwindow.cpp" line="800"/>
-        <location filename="../mainwindow.cpp" line="865"/>
-        <location filename="../mainwindow.cpp" line="982"/>
+        <location filename="mainwindow.ui" line="229"/>
+        <location filename="mainwindow.cpp" line="82"/>
+        <location filename="mainwindow.cpp" line="582"/>
+        <location filename="mainwindow.cpp" line="711"/>
         <source>Select...</source>
         <translation>Választás...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="132"/>
+        <location filename="mainwindow.ui" line="315"/>
         <source>Move right</source>
         <translation>Mozgatás jobbra</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="146"/>
+        <location filename="mainwindow.ui" line="328"/>
         <source>Move left</source>
         <translation>Mozgatás balra</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="273"/>
-        <location filename="../mainwindow.ui" line="338"/>
-        <location filename="../mainwindow.ui" line="514"/>
-        <location filename="../mainwindow.ui" line="579"/>
-        <source>Click to select different color...</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="407"/>
-        <source>Apply style to all</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="414"/>
-        <source>Hover Background</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="442"/>
-        <source>36x36</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="447"/>
-        <source>40x40</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="491"/>
-        <source>Hover Border</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="716"/>
+        <location filename="mainwindow.ui" line="439"/>
         <source>Display help </source>
         <translation>Súgó megjelenítése</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="719"/>
+        <location filename="mainwindow.ui" line="442"/>
         <source>Help</source>
         <translation>Súgó</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="726"/>
+        <location filename="mainwindow.ui" line="449"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="755"/>
+        <location filename="mainwindow.ui" line="478"/>
         <source>About this application</source>
         <translation>Az alkalmazásról</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="758"/>
+        <location filename="mainwindow.ui" line="481"/>
         <source>About...</source>
         <translation>Névjegy...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="765"/>
+        <location filename="mainwindow.ui" line="488"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="797"/>
+        <location filename="mainwindow.ui" line="520"/>
         <source>Quit application</source>
         <translation>Kilépés az alkalmazásból</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="800"/>
+        <location filename="mainwindow.ui" line="523"/>
         <source>Close</source>
         <translation>Bezárás</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="807"/>
+        <location filename="mainwindow.ui" line="530"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="848"/>
+        <location filename="mainwindow.ui" line="571"/>
         <source>Save</source>
         <translation>Mentés</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="855"/>
-        <source>Alt+S</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="128"/>
+        <location filename="mainwindow.cpp" line="103"/>
         <source>1. Add applications to the dock one at a time
 2. Select a .desktop file or enter a command for the application you want
 3. Select icon attributes for size, background (black is standard) and border
@@ -191,134 +148,130 @@
 4. A folytatáshoz nyomja meg az &quot;Alkalmazás hozzáadása&quot; gombot, vagy a befejezéshez a &quot;Mentés&quot; gombot.</translation>
     </message>
     <message>
+        <location filename="mainwindow.cpp" line="126"/>
+        <location filename="mainwindow.cpp" line="590"/>
         <source>black</source>
-        <translation type="vanished">fekete</translation>
+        <translation>fekete</translation>
     </message>
     <message>
+        <location filename="mainwindow.cpp" line="127"/>
+        <location filename="mainwindow.cpp" line="591"/>
         <source>white</source>
-        <translation type="vanished">fehér</translation>
+        <translation>fehér</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="166"/>
+        <location filename="mainwindow.cpp" line="137"/>
         <source>This tool allows you to create a new dock with one or more applications. You can also edit or delete a dock created earlier.</source>
         <translation>Ezzel az eszközzel új dokkot hozhat létre egy vagy több alkalmazással. Egy korábban létrehozott dokkot is szerkeszthet vagy törölhet.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="169"/>
+        <location filename="mainwindow.cpp" line="139"/>
         <source>Operation mode</source>
         <translation>Működési mód</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="175"/>
+        <location filename="mainwindow.cpp" line="140"/>
         <source>&amp;Close</source>
         <translation>&amp;Bezárás</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="171"/>
+        <location filename="mainwindow.cpp" line="141"/>
         <source>&amp;Move</source>
         <translation>&amp;Mozgatás</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="172"/>
+        <location filename="mainwindow.cpp" line="142"/>
+        <location filename="mainwindow.cpp" line="295"/>
         <source>&amp;Delete</source>
         <translation>&amp;Törlés</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="173"/>
+        <location filename="mainwindow.cpp" line="143"/>
         <source>&amp;Edit</source>
         <translation>&amp;Szerkesztés</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="174"/>
+        <location filename="mainwindow.cpp" line="144"/>
         <source>C&amp;reate</source>
         <translation>&amp;Létrehozás</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="288"/>
+        <location filename="mainwindow.cpp" line="220"/>
         <source>Dock name</source>
         <translation>Dokk neve</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="288"/>
+        <location filename="mainwindow.cpp" line="221"/>
         <source>Enter the name to show in the Menu:</source>
         <translation>Adja meg a menüben megjelenítendő nevet:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="389"/>
+        <location filename="mainwindow.cpp" line="293"/>
         <source>Select dock to delete</source>
         <translation>Válassza ki a törölni kívánt dokkot</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="394"/>
+        <location filename="mainwindow.cpp" line="294"/>
         <source>Confirmation</source>
         <translation>Jóváhagyás</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="394"/>
+        <location filename="mainwindow.cpp" line="295"/>
         <source>Are you sure you want to delete %1?</source>
         <translation>Biztos, hogy törölni szeretné ezt: %1?</translation>
     </message>
     <message>
+        <location filename="mainwindow.cpp" line="295"/>
         <source>&amp;Cancel</source>
-        <translation type="vanished">&amp;Mégsem</translation>
+        <translation>&amp;Mégsem</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="172"/>
+        <location filename="mainwindow.ui" line="353"/>
         <source>Next</source>
         <translation>Következő</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="425"/>
+        <location filename="mainwindow.cpp" line="320"/>
         <source>Select dock to move</source>
         <translation>Válassza ki a mozgatni kívánt dokkot</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="390"/>
-        <location filename="../mainwindow.cpp" line="426"/>
-        <location filename="../mainwindow.cpp" line="641"/>
-        <location filename="../mainwindow.cpp" line="926"/>
+        <location filename="mainwindow.cpp" line="293"/>
+        <location filename="mainwindow.cpp" line="320"/>
+        <location filename="mainwindow.cpp" line="454"/>
+        <location filename="mainwindow.cpp" line="657"/>
         <source>Dock Files (*.mxdk);;All Files (*.*)</source>
         <translation>Dokk fájlok (*.mxdk);;Minden fájl (*.*)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="403"/>
-        <source>Error</source>
-        <translation type="unfinished">Hiba</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="403"/>
-        <source>Failed to delete the selected dock.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="436"/>
-        <location filename="../mainwindow.cpp" line="461"/>
-        <location filename="../mainwindow.cpp" line="937"/>
+        <location filename="mainwindow.cpp" line="330"/>
+        <location filename="mainwindow.cpp" line="351"/>
+        <location filename="mainwindow.cpp" line="666"/>
         <source>Could not open file</source>
         <translation>Fájl megnyitása nem sikerült</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="639"/>
+        <location filename="mainwindow.cpp" line="453"/>
         <source>Overwrite?</source>
         <translation>Felülírja?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="639"/>
+        <location filename="mainwindow.cpp" line="453"/>
         <source>Do you want to overwrite the dock file?</source>
         <translation>Felül szeretné írni a dokkfájlt?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="640"/>
+        <location filename="mainwindow.cpp" line="454"/>
         <source>Save file</source>
         <translation>Fájl mentése</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="713"/>
+        <location filename="mainwindow.cpp" line="492"/>
         <source>Dock saved</source>
         <translation>Dokk mentve</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="714"/>
+        <location filename="mainwindow.cpp" line="492"/>
         <source>The dock has been saved.
 
 To edit the newly created dock please select &apos;Edit an existing dock&apos;.</source>
@@ -327,76 +280,71 @@ To edit the newly created dock please select &apos;Edit an existing dock&apos;.<
 Az újonnan létrehozott dokk szerkesztéséhez válassza a &apos;Meglévő dokk szerkesztése&apos; lehetőséget.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="732"/>
+        <location filename="mainwindow.cpp" line="511"/>
         <source>About %1</source>
         <translation>%1 névjegye</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="732"/>
-        <source>MX Dockmaker</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="733"/>
+        <location filename="mainwindow.cpp" line="513"/>
         <source>Version: </source>
         <translation>Verzió:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="734"/>
+        <location filename="mainwindow.cpp" line="514"/>
         <source>Description goes here</source>
         <translation>Leírás helye</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="737"/>
+        <location filename="mainwindow.cpp" line="516"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="738"/>
+        <location filename="mainwindow.cpp" line="517"/>
         <source>%1 License</source>
         <translation>%1 licenc</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="747"/>
+        <location filename="mainwindow.cpp" line="526"/>
         <source>%1 Help</source>
         <translation>%1 Súgó</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="904"/>
+        <location filename="mainwindow.cpp" line="638"/>
         <source>Select .desktop file</source>
         <translation>Válassza ki a .desktop fájlt</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="905"/>
+        <location filename="mainwindow.cpp" line="638"/>
         <source>Desktop Files (*.desktop)</source>
         <translation>Desktop fájlok (*.desktop)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="925"/>
+        <location filename="mainwindow.cpp" line="657"/>
         <source>Select a dock file</source>
         <translation>Válasszon ki egy dokk fájlt</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="930"/>
+        <location filename="mainwindow.cpp" line="660"/>
         <source>No file selected</source>
         <translation>Nincs kijelölt fájl</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="931"/>
-        <source>You haven&apos;t selected any dock file to edit.
+        <location filename="mainwindow.cpp" line="660"/>
+        <source>You haven't selected any dock file to edit.
 Creating a new dock instead.</source>
         <translation>Nem választott ki dokkfájlt szerkesztésre.
 Új dokk kerül létrehozásra.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="938"/>
+        <location filename="mainwindow.cpp" line="666"/>
         <source>Could not open selected file.
 Creating a new dock instead.</source>
         <translation>Nem sikerült a kiválasztott fájl megnyitása.
 Inkább egy új dokk kerül létrehozásra.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="946"/>
+        <location filename="mainwindow.cpp" line="675"/>
         <source>1. Edit applications one at a time using the Back and Next buttons
 2. Add or delete applications as you like
 3. When finished click Save</source>
@@ -405,12 +353,12 @@ Inkább egy új dokk kerül létrehozásra.</translation>
 3. Ha végzett, kattintson a Mentés gombra.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1023"/>
+        <location filename="mainwindow.cpp" line="719"/>
         <source>Select icon</source>
         <translation>Válasszon ikont</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1024"/>
+        <location filename="mainwindow.cpp" line="719"/>
         <source>Icons (*.png *.jpg *.bmp *.xpm *.svg)</source>
         <translation>Ikonok (*.png *.jpg *.bmp *.xpm *.svg)</translation>
     </message>
@@ -418,77 +366,77 @@ Inkább egy új dokk kerül létrehozásra.</translation>
 <context>
     <name>PickLocation</name>
     <message>
-        <location filename="../picklocation.ui" line="14"/>
+        <location filename="picklocation.ui" line="14"/>
         <source>Dialog</source>
         <translation>Dialógus</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="23"/>
+        <location filename="picklocation.ui" line="23"/>
         <source>Dock Location</source>
         <translation>Dokk helye</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="29"/>
+        <location filename="picklocation.ui" line="29"/>
         <source>TopCenter</source>
         <translation>Fent középen</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="45"/>
+        <location filename="picklocation.ui" line="45"/>
         <source>BottomLeft</source>
         <translation>Lent balra</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="61"/>
+        <location filename="picklocation.ui" line="61"/>
         <source>BottomCenter</source>
         <translation>Lent középen</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="80"/>
+        <location filename="picklocation.ui" line="80"/>
         <source>TopLeft</source>
         <translation>Fent balra</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="96"/>
+        <location filename="picklocation.ui" line="96"/>
         <source>TopRight</source>
         <translation>Fent jobbra</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="112"/>
+        <location filename="picklocation.ui" line="112"/>
         <source>LeftCenter</source>
         <translation>Balra középen</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="128"/>
+        <location filename="picklocation.ui" line="128"/>
         <source>RightCenter</source>
         <translation>Jobbra középen</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="144"/>
+        <location filename="picklocation.ui" line="144"/>
         <source>BottomRight</source>
         <translation>Lent jobbra</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="160"/>
+        <location filename="picklocation.ui" line="160"/>
         <source>RightTop</source>
         <translation>Jobbra fent</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="173"/>
+        <location filename="picklocation.ui" line="173"/>
         <source>LeftTop</source>
         <translation>Balra fent</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="189"/>
+        <location filename="picklocation.ui" line="189"/>
         <source>LeftBottom</source>
         <translation>Balra lent</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="205"/>
+        <location filename="picklocation.ui" line="205"/>
         <source>RightBottom</source>
         <translation>Jobbra lent</translation>
     </message>
     <message>
-        <location filename="../picklocation.cpp" line="9"/>
+        <location filename="picklocation.cpp" line="9"/>
         <source>Select dock location</source>
         <translation>Válassza ki a dokk helyét</translation>
     </message>
@@ -496,68 +444,35 @@ Inkább egy új dokk kerül létrehozásra.</translation>
 <context>
     <name>QApplication</name>
     <message>
+        <location filename="about.cpp" line="32"/>
         <source>License</source>
-        <translation type="vanished">Licenc</translation>
+        <translation>Licenc</translation>
     </message>
     <message>
+        <location filename="about.cpp" line="33"/>
+        <location filename="about.cpp" line="43"/>
         <source>Changelog</source>
-        <translation type="vanished">Változások listája</translation>
+        <translation>Változások listája</translation>
     </message>
     <message>
+        <location filename="about.cpp" line="34"/>
         <source>Cancel</source>
-        <translation type="vanished">Mégsem</translation>
+        <translation>Mégsem</translation>
     </message>
     <message>
+        <location filename="about.cpp" line="51"/>
         <source>&amp;Close</source>
-        <translation type="vanished">&amp;Bezárás</translation>
+        <translation>&amp;Bezárás</translation>
     </message>
     <message>
+        <location filename="main.cpp" line="57"/>
         <source>Error</source>
-        <translation type="vanished">Hiba</translation>
+        <translation>Hiba</translation>
     </message>
     <message>
+        <location filename="main.cpp" line="58"/>
         <source>You must run this program as normal user.</source>
-        <translation type="vanished">Egyszerű felhasználóként kell futtatnia ezt a programot.</translation>
+        <translation>Egyszerű felhasználóként kell futtatnia ezt a programot.</translation>
     </message>
 </context>
-<context>
-    <name>QObject</name>
-    <message>
-        <location filename="../about.cpp" line="41"/>
-        <source>License</source>
-        <translation type="unfinished">Licenc</translation>
-    </message>
-    <message>
-        <location filename="../about.cpp" line="42"/>
-        <location filename="../about.cpp" line="51"/>
-        <source>Changelog</source>
-        <translation type="unfinished">Változások listája</translation>
-    </message>
-    <message>
-        <location filename="../about.cpp" line="43"/>
-        <source>Cancel</source>
-        <translation type="unfinished">Mégsem</translation>
-    </message>
-    <message>
-        <location filename="../about.cpp" line="64"/>
-        <source>&amp;Close</source>
-        <translation type="unfinished">&amp;Bezárás</translation>
-    </message>
-    <message>
-        <location filename="../main.cpp" line="59"/>
-        <location filename="../main.cpp" line="75"/>
-        <source>Error</source>
-        <translation type="unfinished">Hiba</translation>
-    </message>
-    <message>
-        <location filename="../main.cpp" line="60"/>
-        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main.cpp" line="75"/>
-        <source>You must run this program as normal user.</source>
-        <translation type="unfinished">Egyszerű felhasználóként kell futtatnia ezt a programot.</translation>
-    </message>
-</context>
-</TS>
+</TS>
\ No newline at end of file
