@@ -1,186 +1,143 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="nl">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.0" language="nl">
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.ui" line="14"/>
+        <location filename="mainwindow.ui" line="14"/>
         <source>Program_Name</source>
         <translation>Programma_Naam</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="29"/>
+        <location filename="mainwindow.ui" line="29"/>
         <source>Usage</source>
         <translation>Gebruik</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="229"/>
+        <location filename="mainwindow.ui" line="106"/>
         <source>Dock Preview</source>
         <translation>Dock Voorbeeld</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="241"/>
+        <location filename="mainwindow.ui" line="118"/>
         <source>Add New Application</source>
         <translation>Nieuwe Applicatie Toevoegen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="641"/>
+        <location filename="mainwindow.ui" line="131"/>
         <source>Command</source>
         <translation>Commando</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="118"/>
+        <location filename="mainwindow.ui" line="301"/>
         <source>Add application</source>
         <translation>Applicatie toevoegen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="212"/>
+        <location filename="mainwindow.ui" line="393"/>
         <source>Delete this application</source>
         <translation>Verwijder deze applicatie</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="400"/>
+        <location filename="mainwindow.ui" line="124"/>
         <source>Border</source>
         <translation>Rand</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="247"/>
+        <location filename="mainwindow.ui" line="154"/>
         <source>Size</source>
         <translation>Grootte</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="664"/>
+        <location filename="mainwindow.ui" line="161"/>
         <source>Background</source>
         <translation>Achtergrond</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="198"/>
+        <location filename="mainwindow.ui" line="379"/>
         <source>Back</source>
         <translation>Terug</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="465"/>
+        <location filename="mainwindow.ui" line="184"/>
         <source>File</source>
         <translation>Bestand</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="504"/>
-        <location filename="../mainwindow.cpp" line="861"/>
-        <location filename="../mainwindow.cpp" line="979"/>
-        <location filename="../mainwindow.cpp" line="1017"/>
-        <location filename="../mainwindow.cpp" line="1042"/>
+        <location filename="mainwindow.ui" line="216"/>
+        <location filename="mainwindow.cpp" line="708"/>
+        <location filename="mainwindow.cpp" line="735"/>
         <source>Select icon...</source>
         <translation>Selecteer icoon...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="677"/>
-        <location filename="../mainwindow.cpp" line="102"/>
-        <location filename="../mainwindow.cpp" line="800"/>
-        <location filename="../mainwindow.cpp" line="865"/>
-        <location filename="../mainwindow.cpp" line="982"/>
+        <location filename="mainwindow.ui" line="229"/>
+        <location filename="mainwindow.cpp" line="82"/>
+        <location filename="mainwindow.cpp" line="582"/>
+        <location filename="mainwindow.cpp" line="711"/>
         <source>Select...</source>
         <translation>Selecteer...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="132"/>
+        <location filename="mainwindow.ui" line="315"/>
         <source>Move right</source>
         <translation>Beweeg naar rechts</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="146"/>
+        <location filename="mainwindow.ui" line="328"/>
         <source>Move left</source>
         <translation>Beweeg naar links</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="273"/>
-        <location filename="../mainwindow.ui" line="338"/>
-        <location filename="../mainwindow.ui" line="514"/>
-        <location filename="../mainwindow.ui" line="579"/>
-        <source>Click to select different color...</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="407"/>
-        <source>Apply style to all</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="414"/>
-        <source>Hover Background</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="442"/>
-        <source>36x36</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="447"/>
-        <source>40x40</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="491"/>
-        <source>Hover Border</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="716"/>
+        <location filename="mainwindow.ui" line="439"/>
         <source>Display help </source>
         <translation>Toon help</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="719"/>
+        <location filename="mainwindow.ui" line="442"/>
         <source>Help</source>
         <translation>Hulp</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="726"/>
+        <location filename="mainwindow.ui" line="449"/>
         <source>Alt+H</source>
         <translation>Alt+H</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="755"/>
+        <location filename="mainwindow.ui" line="478"/>
         <source>About this application</source>
         <translation>Over deze toepassing</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="758"/>
+        <location filename="mainwindow.ui" line="481"/>
         <source>About...</source>
         <translation>Over...</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="765"/>
+        <location filename="mainwindow.ui" line="488"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="797"/>
+        <location filename="mainwindow.ui" line="520"/>
         <source>Quit application</source>
         <translation>Verlaat de applicatie</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="800"/>
+        <location filename="mainwindow.ui" line="523"/>
         <source>Close</source>
         <translation>Sluiten</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="807"/>
+        <location filename="mainwindow.ui" line="530"/>
         <source>Alt+N</source>
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="848"/>
+        <location filename="mainwindow.ui" line="571"/>
         <source>Save</source>
         <translation>Opslaan</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="855"/>
-        <source>Alt+S</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="128"/>
+        <location filename="mainwindow.cpp" line="103"/>
         <source>1. Add applications to the dock one at a time
 2. Select a .desktop file or enter a command for the application you want
 3. Select icon attributes for size, background (black is standard) and border
@@ -191,134 +148,130 @@
 4. Druk op &quot;Applicatie toevoegen&quot; om verder te gaan of op &quot;Opslaan&quot; om te eindigen</translation>
     </message>
     <message>
+        <location filename="mainwindow.cpp" line="126"/>
+        <location filename="mainwindow.cpp" line="590"/>
         <source>black</source>
-        <translation type="vanished">zwart</translation>
+        <translation>zwart</translation>
     </message>
     <message>
+        <location filename="mainwindow.cpp" line="127"/>
+        <location filename="mainwindow.cpp" line="591"/>
         <source>white</source>
-        <translation type="vanished">wit</translation>
+        <translation>wit</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="166"/>
+        <location filename="mainwindow.cpp" line="137"/>
         <source>This tool allows you to create a new dock with one or more applications. You can also edit or delete a dock created earlier.</source>
         <translation>Met dit gereedschap kunt u een nieuwe dock creëren met één of meerdere toepassingen. U kunt ook een eerder aangemaakt dock bewerken of verwijderen.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="169"/>
+        <location filename="mainwindow.cpp" line="139"/>
         <source>Operation mode</source>
         <translation>Werk modus</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="175"/>
+        <location filename="mainwindow.cpp" line="140"/>
         <source>&amp;Close</source>
         <translation>&amp;Sluiten</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="171"/>
+        <location filename="mainwindow.cpp" line="141"/>
         <source>&amp;Move</source>
         <translation>&amp;Verplaats</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="172"/>
+        <location filename="mainwindow.cpp" line="142"/>
+        <location filename="mainwindow.cpp" line="295"/>
         <source>&amp;Delete</source>
         <translation>&amp;Delete</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="173"/>
+        <location filename="mainwindow.cpp" line="143"/>
         <source>&amp;Edit</source>
         <translation>&amp;Aanpassen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="174"/>
+        <location filename="mainwindow.cpp" line="144"/>
         <source>C&amp;reate</source>
         <translation>&amp;Creëer</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="288"/>
+        <location filename="mainwindow.cpp" line="220"/>
         <source>Dock name</source>
         <translation>Dock naam</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="288"/>
+        <location filename="mainwindow.cpp" line="221"/>
         <source>Enter the name to show in the Menu:</source>
         <translation>Voer de naam in die in het Menu te zien is:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="389"/>
+        <location filename="mainwindow.cpp" line="293"/>
         <source>Select dock to delete</source>
         <translation>Selecteer dock die u wilt verwijderen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="394"/>
+        <location filename="mainwindow.cpp" line="294"/>
         <source>Confirmation</source>
         <translation>Bevestiging</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="394"/>
+        <location filename="mainwindow.cpp" line="295"/>
         <source>Are you sure you want to delete %1?</source>
         <translation>Weet U zeker dat U %1 wilt verwijderen?</translation>
     </message>
     <message>
+        <location filename="mainwindow.cpp" line="295"/>
         <source>&amp;Cancel</source>
-        <translation type="vanished">&amp;Cancel</translation>
+        <translation>&amp;Cancel</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="172"/>
+        <location filename="mainwindow.ui" line="353"/>
         <source>Next</source>
         <translation>Volgende</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="425"/>
+        <location filename="mainwindow.cpp" line="320"/>
         <source>Select dock to move</source>
         <translation>Selecteer dock om te verplaatsen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="390"/>
-        <location filename="../mainwindow.cpp" line="426"/>
-        <location filename="../mainwindow.cpp" line="641"/>
-        <location filename="../mainwindow.cpp" line="926"/>
+        <location filename="mainwindow.cpp" line="293"/>
+        <location filename="mainwindow.cpp" line="320"/>
+        <location filename="mainwindow.cpp" line="454"/>
+        <location filename="mainwindow.cpp" line="657"/>
         <source>Dock Files (*.mxdk);;All Files (*.*)</source>
         <translation>Dock Bestanden (*.mxdk);;Alle Bestanden (*.*)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="403"/>
-        <source>Error</source>
-        <translation type="unfinished">Fout</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="403"/>
-        <source>Failed to delete the selected dock.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="436"/>
-        <location filename="../mainwindow.cpp" line="461"/>
-        <location filename="../mainwindow.cpp" line="937"/>
+        <location filename="mainwindow.cpp" line="330"/>
+        <location filename="mainwindow.cpp" line="351"/>
+        <location filename="mainwindow.cpp" line="666"/>
         <source>Could not open file</source>
         <translation>Kon bestand niet openen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="639"/>
+        <location filename="mainwindow.cpp" line="453"/>
         <source>Overwrite?</source>
         <translation>Overschrijven?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="639"/>
+        <location filename="mainwindow.cpp" line="453"/>
         <source>Do you want to overwrite the dock file?</source>
         <translation>Wilt u het dock bestand overschrijven?</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="640"/>
+        <location filename="mainwindow.cpp" line="454"/>
         <source>Save file</source>
         <translation>Bestand opslaan</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="713"/>
+        <location filename="mainwindow.cpp" line="492"/>
         <source>Dock saved</source>
         <translation>Dock opgeslagen</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="714"/>
+        <location filename="mainwindow.cpp" line="492"/>
         <source>The dock has been saved.
 
 To edit the newly created dock please select &apos;Edit an existing dock&apos;.</source>
@@ -327,76 +280,71 @@ To edit the newly created dock please select &apos;Edit an existing dock&apos;.<
 Om het nieuw aangemaakte dock te bewerken selecteert u &apos;Bewerk een bestaand dock&apos;.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="732"/>
+        <location filename="mainwindow.cpp" line="511"/>
         <source>About %1</source>
         <translation>Over %1</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="732"/>
-        <source>MX Dockmaker</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.cpp" line="733"/>
+        <location filename="mainwindow.cpp" line="513"/>
         <source>Version: </source>
         <translation>Versie:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="734"/>
+        <location filename="mainwindow.cpp" line="514"/>
         <source>Description goes here</source>
         <translation>Beschrijving komt hier</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="737"/>
+        <location filename="mainwindow.cpp" line="516"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="738"/>
+        <location filename="mainwindow.cpp" line="517"/>
         <source>%1 License</source>
         <translation>%1 Licentie</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="747"/>
+        <location filename="mainwindow.cpp" line="526"/>
         <source>%1 Help</source>
         <translation>%1 Help</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="904"/>
+        <location filename="mainwindow.cpp" line="638"/>
         <source>Select .desktop file</source>
         <translation>Kies .desktop bestand</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="905"/>
+        <location filename="mainwindow.cpp" line="638"/>
         <source>Desktop Files (*.desktop)</source>
         <translation>Desktop Bestanden (*.desktop)</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="925"/>
+        <location filename="mainwindow.cpp" line="657"/>
         <source>Select a dock file</source>
         <translation>Selecteer een dock bestand</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="930"/>
+        <location filename="mainwindow.cpp" line="660"/>
         <source>No file selected</source>
         <translation>Geen bestand geselecteerd</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="931"/>
-        <source>You haven&apos;t selected any dock file to edit.
+        <location filename="mainwindow.cpp" line="660"/>
+        <source>You haven't selected any dock file to edit.
 Creating a new dock instead.</source>
         <translation>U hebt geen enkel dockbestand geselecteerd om te bewerken.
 In plaats daarvan nieuw dock creëren.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="938"/>
+        <location filename="mainwindow.cpp" line="666"/>
         <source>Could not open selected file.
 Creating a new dock instead.</source>
         <translation>Kon geselecteerd bestand niet openen.
 In plaats daarvan nieuw dock creëren.</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="946"/>
+        <location filename="mainwindow.cpp" line="675"/>
         <source>1. Edit applications one at a time using the Back and Next buttons
 2. Add or delete applications as you like
 3. When finished click Save</source>
@@ -405,12 +353,12 @@ In plaats daarvan nieuw dock creëren.</translation>
 3. Wanneer klaar druk op Opslaan</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1023"/>
+        <location filename="mainwindow.cpp" line="719"/>
         <source>Select icon</source>
         <translation>Selecteer icoon</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="1024"/>
+        <location filename="mainwindow.cpp" line="719"/>
         <source>Icons (*.png *.jpg *.bmp *.xpm *.svg)</source>
         <translation>Iconen (*.png *.jpg *.bmp *.xpm *.svg)</translation>
     </message>
@@ -418,77 +366,77 @@ In plaats daarvan nieuw dock creëren.</translation>
 <context>
     <name>PickLocation</name>
     <message>
-        <location filename="../picklocation.ui" line="14"/>
+        <location filename="picklocation.ui" line="14"/>
         <source>Dialog</source>
         <translation>Dialoog</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="23"/>
+        <location filename="picklocation.ui" line="23"/>
         <source>Dock Location</source>
         <translation>Dock Locatie</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="29"/>
+        <location filename="picklocation.ui" line="29"/>
         <source>TopCenter</source>
         <translation>BovenMidden</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="45"/>
+        <location filename="picklocation.ui" line="45"/>
         <source>BottomLeft</source>
         <translation>OnderLinks</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="61"/>
+        <location filename="picklocation.ui" line="61"/>
         <source>BottomCenter</source>
         <translation>OnderMidden</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="80"/>
+        <location filename="picklocation.ui" line="80"/>
         <source>TopLeft</source>
         <translation>BovenLinks</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="96"/>
+        <location filename="picklocation.ui" line="96"/>
         <source>TopRight</source>
         <translation>BovenRechts</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="112"/>
+        <location filename="picklocation.ui" line="112"/>
         <source>LeftCenter</source>
         <translation>LinksMidden</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="128"/>
+        <location filename="picklocation.ui" line="128"/>
         <source>RightCenter</source>
         <translation>RechtsMidden</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="144"/>
+        <location filename="picklocation.ui" line="144"/>
         <source>BottomRight</source>
         <translation>OnderRechts</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="160"/>
+        <location filename="picklocation.ui" line="160"/>
         <source>RightTop</source>
         <translation>RechtsBoven</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="173"/>
+        <location filename="picklocation.ui" line="173"/>
         <source>LeftTop</source>
         <translation>LinksBoven</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="189"/>
+        <location filename="picklocation.ui" line="189"/>
         <source>LeftBottom</source>
         <translation>LinksOnder</translation>
     </message>
     <message>
-        <location filename="../picklocation.ui" line="205"/>
+        <location filename="picklocation.ui" line="205"/>
         <source>RightBottom</source>
         <translation>RechtsOnder</translation>
     </message>
     <message>
-        <location filename="../picklocation.cpp" line="9"/>
+        <location filename="picklocation.cpp" line="9"/>
         <source>Select dock location</source>
         <translation>Selecteer dock locatie</translation>
     </message>
@@ -496,68 +444,35 @@ In plaats daarvan nieuw dock creëren.</translation>
 <context>
     <name>QApplication</name>
     <message>
+        <location filename="about.cpp" line="32"/>
         <source>License</source>
-        <translation type="vanished">Licentie</translation>
+        <translation>Licentie</translation>
     </message>
     <message>
+        <location filename="about.cpp" line="33"/>
+        <location filename="about.cpp" line="43"/>
         <source>Changelog</source>
-        <translation type="vanished">Changelog</translation>
+        <translation>Changelog</translation>
     </message>
     <message>
+        <location filename="about.cpp" line="34"/>
         <source>Cancel</source>
-        <translation type="vanished">Ongedaan maken</translation>
+        <translation>Ongedaan maken</translation>
     </message>
     <message>
+        <location filename="about.cpp" line="51"/>
         <source>&amp;Close</source>
-        <translation type="vanished">&amp;Close</translation>
+        <translation>&amp;Close</translation>
     </message>
     <message>
+        <location filename="main.cpp" line="57"/>
         <source>Error</source>
-        <translation type="vanished">Fout</translation>
+        <translation>Fout</translation>
     </message>
     <message>
+        <location filename="main.cpp" line="58"/>
         <source>You must run this program as normal user.</source>
-        <translation type="vanished">U moet dit programma als normale gebruiker uitvoeren.</translation>
+        <translation>U moet dit programma als normale gebruiker uitvoeren.</translation>
     </message>
 </context>
-<context>
-    <name>QObject</name>
-    <message>
-        <location filename="../about.cpp" line="41"/>
-        <source>License</source>
-        <translation type="unfinished">Licentie</translation>
-    </message>
-    <message>
-        <location filename="../about.cpp" line="42"/>
-        <location filename="../about.cpp" line="51"/>
-        <source>Changelog</source>
-        <translation type="unfinished">Changelog</translation>
-    </message>
-    <message>
-        <location filename="../about.cpp" line="43"/>
-        <source>Cancel</source>
-        <translation type="unfinished">Ongedaan maken</translation>
-    </message>
-    <message>
-        <location filename="../about.cpp" line="64"/>
-        <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main.cpp" line="59"/>
-        <location filename="../main.cpp" line="75"/>
-        <source>Error</source>
-        <translation type="unfinished">Fout</translation>
-    </message>
-    <message>
-        <location filename="../main.cpp" line="60"/>
-        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <location filename="../main.cpp" line="75"/>
-        <source>You must run this program as normal user.</source>
-        <translation type="unfinished">U moet dit programma als normale gebruiker uitvoeren.</translation>
-    </message>
-</context>
-</TS>
+</TS>
\ No newline at end of file
